"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createGetModulesMethod = void 0;
const read_assets_manifest_1 = require("../read-assets-manifest");
function createGetModulesMethod(modules) {
    const assets = {};
    return {
        method: 'POST',
        path: '/api/getModuleResources',
        handler: (getResourcesRequest, ...params) => __awaiter(this, void 0, void 0, function* () {
            var _a;
            const appManifest = yield (0, read_assets_manifest_1.getAppManifest)();
            const moduleName = getResourcesRequest.moduleId;
            if (!modules[moduleName]) {
                throw new Error(`Module ${moduleName} not found`);
            }
            const module = modules[moduleName];
            if (module.mountMode === 'compat' && !assets[moduleName]) {
                assets[moduleName] = yield (0, read_assets_manifest_1.readAssetsManifest)([`vendor-${moduleName}`, moduleName]);
            }
            if (module.mountMode === 'default') {
                // для default модулей мы всегда берем просто remoteEntry, это стандартный энтрипоинт для module federation
                // загрузку стилей при этом на себя берет сам module federation.
                assets[moduleName] = {
                    js: ['assets/remoteEntry.js'],
                    css: [],
                };
            }
            const moduleAssets = assets[moduleName];
            const moduleRunParams = yield module.getModuleState(getResourcesRequest, ...params);
            return {
                mountMode: module.mountMode,
                moduleVersion: (_a = module.version) !== null && _a !== void 0 ? _a : 'unknown',
                scripts: moduleAssets.js,
                styles: moduleAssets.css,
                moduleState: moduleRunParams,
                appName: appManifest.__metadata__.name,
            };
        })
    };
}
exports.createGetModulesMethod = createGetModulesMethod;
