"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.readAssetsManifest = exports.getAppManifest = void 0;
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const util_1 = require("util");
const readFile = (0, util_1.promisify)(fs_1.default.readFile);
const DEFAULT_BUNDLE_NAMES = ['vendor', 'internalVendor', 'main'];
let appManifest;
function getAppManifest() {
    return __awaiter(this, void 0, void 0, function* () {
        if (!appManifest) {
            const manifestPath = path_1.default.join(process.cwd(), '.build/webpack-assets.json');
            const fileContent = yield readFile(manifestPath, 'utf8');
            appManifest = JSON.parse(fileContent);
        }
        return appManifest;
    });
}
exports.getAppManifest = getAppManifest;
function readAssetsManifest(bundleNames = DEFAULT_BUNDLE_NAMES) {
    return __awaiter(this, void 0, void 0, function* () {
        const manifest = yield getAppManifest();
        const js = [];
        const css = [];
        bundleNames.forEach((key) => {
            if (!manifest[key]) {
                return;
            }
            const script = manifest[key].js;
            if (script) {
                js.push(script);
            }
            const style = manifest[key].css;
            if (style) {
                css.push(style);
            }
        });
        return {
            js,
            css,
        };
    });
}
exports.readAssetsManifest = readAssetsManifest;
